@@ -84,7 +84,7 @@
 #define KDECLARATIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECLARATIVE_NO_DEPRECATED
-#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
+#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
 #endif
 #ifdef KDECLARATIVE_NO_DEPRECATED_WARNINGS
 #  define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x56a00
+#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x56d00
 #  endif
 #endif
 
